# -*- coding: UTF-8 -*-

__revision__ = '$Id: version.py 1372 2010-01-04 21:20:40Z piotrek $'

# Copyright © 2005-2010 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

pname = 'Griffith'
pversion = '0.11'
pauthor = 'Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>'
pyear = '2005-2010'
pwebsite = 'http://www.griffith.cc/'
pdescription = _('Griffith is a film collection manager.')
